﻿using System.Collections.Generic;
using System.Linq;

using Prism.Commands;
using Prism.Mvvm;

namespace TestProject.ViewModels
{
    /// <summary>
    /// 메인 윈도우 뷰
    /// </summary>
    public class MainWindowViewModel : BindableBase
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 제목
        /// </summary>
        private string title = "InvokeCommandAction 클래스 : 이벤트에 반응해 명령 호출하기";

        /// <summary>
        /// 선택 항목 텍스트
        /// </summary>
        private string selectedItemText;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 제목 - Title

        /// <summary>
        /// 제목
        /// </summary>
        public string Title
        {
            get
            {
                return this.title;
            }
            set
            {
                SetProperty(ref this.title, value);
            }
        }

        #endregion
        #region 선택 항목 텍스트 - SelectedItemText

        /// <summary>
        /// 선택 항목 텍스트
        /// </summary>
        public string SelectedItemText
        {
            get
            {
                return this.selectedItemText;
            }
            private set
            {
                SetProperty(ref this.selectedItemText, value);
            }
        }

        #endregion
        #region 항목 리스트 - Items

        /// <summary>
        /// 항목 리스트
        /// </summary>
        public IList<string> Items { get; private set; }

        #endregion
        #region 선택 명령 - SelectCommand

        /// <summary>
        /// 선택 명령
        /// </summary>
        public DelegateCommand<object[]> SelectCommand { get; private set; }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindowViewModel()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindowViewModel()
        {
            Items = new List<string>();

            Items.Add("Item1");
            Items.Add("Item2");
            Items.Add("Item3");
            Items.Add("Item4");
            Items.Add("Item5");

            SelectCommand = new DelegateCommand<object[]>(Select);
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 선택하기 - Select(selectedItemArray)

        /// <summary>
        /// 선택하기
        /// </summary>
        /// <param name="selectedItemArray">선택 항목 배열</param>
        private void Select(object[] selectedItemArray)
        {
            if(selectedItemArray != null && selectedItemArray.Count() > 0)
            {
                SelectedItemText = selectedItemArray.FirstOrDefault().ToString();
            }
        }

        #endregion
    }
}